<?php

/** @noinspection PhpUndefinedClassInspection */
/** @noinspection PhpFullyQualifiedNameUsageInspection */
/** @noinspection PhpUnusedAliasInspection */

namespace Inertia {

    /**
     * @method self tag(string $html, ...$vars)
     * @method self title(string|null $title, string|false|\Closure|null $template = null)
     * @method self titleTemplate(string|\Closure $template)
     * @method self description(string $description)
     * @method self image(string $image)
     * @method self ogMeta(array $ogMeta = [])
     * @method self ogUrl(string|null $url = null)
     * @method self ogTitle(string|null $title = null)
     * @method self ogDescription(string|null $description = null)
     * @method self ogImage(string|array|null $image = null)
     * @method self ogVideo(array $video)
     * @method self ogType(string|null $type = 'website')
     * @method self ogLocale(string $locale)
     * @method self fbAppID(string|null $id = null)
     * @method self twitterCard(string|null $type = 'summary')
     * @method self twitterSummaryCard(array meta = [])
     * @method self twitterLargeCard(array meta = [])
     * @method self twitterAppCard(array meta = [])
     * @method self twitterPlayerCard(array meta = [])
     * @method self twitterTitle(string|null $title = null)
     * @method self twitterDescription(string|null $description = null)
     * @method self twitterImage(string|null $image = null, string|null $alt = null)
     * @method self twitterSite(string|null $username = null, string|null $id = null)
     * @method self twitterCreator(string|null $username = null, string|null $id = null)
     * @method self twitterAppForIphone(array $app = [])
     * @method self twitterAppForIpad(array $app = [])
     * @method self twitterAppForGoogleplay(array $app = [])
     * @method self twitterAppCountry(string $country)
     * @method self twitterPlayer(array $player)
     *
     * @see \Inertia\SSRHead\ResponseMacros
     * @see \Inertia\SSRHead\HeadManager
     */
    class Response
    {
        //
    }

    /**
     * @method static self titleTemplate(string|\Closure $template)
     *
     * @see \Inertia\SSRHead\HeadManager
     */
    class Inertia
    {
        //
    }
}
